Learn R Programming

ggincerta (version 0.1.0)

StatGlyph: Generate glyph maps on sf objects

Description

geom_sf_glyph() adds a glyph map layer based on simple feature (sf) objects to a ggplot. A glyph map is essentially a centroid-based map, where each region is represented by a rotated glyph, and the rotation angle indicates the value of v2 specified in the mapping.

Usage

StatGlyph

geom_sf_glyph( mapping = NULL, data = NULL, size = 70, style = "icone", max_v2 = NULL, position = "identity", show.legend = TRUE, inherit.aes = TRUE, ... )

Value

A list of ggplot2 layer objects.

Format

An object of class StatGlyph (inherits from StatSf, Stat, ggproto, gg) of length 3.

Arguments

mapping

Set of aesthetic mappings created by ggplot2::aes(). v1 and v2 are required, which are the variables used for glyph fill and rotation, respectively.

data

The data to be displayed in this layer. There are three options:

If NULL, the default, the data is inherited from the plot data as specified in the call to ggplot().

A data.frame, or other object, will override the plot data. All objects will be fortified to produce a data frame. See fortify() for which variables will be created.

A function will be called with a single argument, the plot data. The return value must be a data.frame, and will be used as the layer data. A function can be created from a formula (e.g. ~ head(.x, 10)).

size

A positive numeric scaling factor controlling glyph size. Larger values produce smaller glyphs.

style

Either "icone" or "semi". Controls the glyph shape.

max_v2

Numeric value setting the upper limit for v2.

position

A position adjustment to use on the data for this layer. This can be used in various ways, including to prevent overplotting and improving the display. The position argument accepts the following:

  • The result of calling a position function, such as position_jitter(). This method allows for passing extra arguments to the position.

  • A string naming the position adjustment. To give the position as a string, strip the function name of the position_ prefix. For example, to use position_jitter(), give the position as "jitter".

  • For more information and other ways to specify the position, see the layer position documentation.

show.legend

logical. Should this layer be included in the legends? NA, the default, includes if any aesthetics are mapped. FALSE never includes, and TRUE always includes.

You can also set this to one of "polygon", "line", and "point" to override the default legend.

inherit.aes

If FALSE, overrides the default aesthetics, rather than combining with them. This is most useful for helper functions that define both data and aesthetics and shouldn't inherit behaviour from the default plot specification, e.g. annotation_borders().

...

Other arguments passed on to layer()'s params argument. These arguments broadly fall into one of 4 categories below. Notably, further arguments to the position argument, or aesthetics that are required can not be passed through .... Unknown arguments that are not part of the 4 categories below are ignored.

  • Static aesthetics that are not mapped to a scale, but are at a fixed value and apply to the layer as a whole. For example, colour = "red" or linewidth = 3. The geom's documentation has an Aesthetics section that lists the available options. The 'required' aesthetics cannot be passed on to the params. Please note that while passing unmapped aesthetics as vectors is technically possible, the order and required length is not guaranteed to be parallel to the input data.

  • When constructing a layer using a stat_*() function, the ... argument can be used to pass on parameters to the geom part of the layer. An example of this is stat_density(geom = "area", outline.type = "both"). The geom's documentation lists which parameters it can accept.

  • Inversely, when constructing a layer using a geom_*() function, the ... argument can be used to pass on parameters to the stat part of the layer. An example of this is geom_area(stat = "density", adjust = 0.5). The stat's documentation lists which parameters it can accept.

  • The key_glyph argument of layer() may also be passed on through .... This can be one of the functions described as key glyphs, to change the display of the layer in the legend.

Glyph map layer contents

The layer returned by geom_sf_glyph() actually contains two scales, corresponding to the two variables specified in the mapping. Therefore, modifying the scale for v1 will trigger a warning indicating that the scale for fill is being replaced.

Examples

Run this code
# Basic glyph map
p <- ggplot(nc) + geom_sf_glyph(mapping = aes(v1 = value, v2 = sd))
p1 <- ggplot(nc) + geom_sf_glyph(mapping = aes(v1 = value, v2 = sd), style = "semi")

# Customize labels and theme
p + labs(title = "glyph map on nc") + theme(legend.position = "left", legend.box = "horizontal")

# Replacing the internal fill scale triggers a message
# ("Scale for fill is already present. Adding another scale for fill...")
p + scale_fill_distiller(palette = "Blues")

Run the code above in your browser using DataLab