Learn R Programming

ggincerta (version 0.1.0)

nc: North Carolina SIDS data

Description

The dataset nc is derived from the North Carolina shapefile (nc.shp) included in the sf package. Two random variables, value and sd, have been added for demonstration purposes.

Further details about the original data can be found in the spdep package vignette.

Usage

nc

Arguments

Format

A sf object.

Examples

Run this code
head(nc)

plot(sf::st_geometry(nc))

Run the code above in your browser using DataLab