Learn R Programming

ggincerta (version 0.1.0)

ggincerta-package: ggincerta: Extend 'ggplot2' with Layers and Scales for Spatial Uncertainty Visualization

Description

Provide specialized 'ggplot2' layers and scales for spatial uncertainty visualization, including bivariate choropleth maps, pixel maps, glyph maps, and exceedance probability maps.

Arguments

Author

Maintainer: Xueqi Ma maggiexma07@gmail.com [copyright holder]

Authors:

Other contributors:

  • Weihao Li [thesis advisor]

  • Quan Vu [thesis advisor]

  • Francis Hui [thesis advisor]

See Also